@@ -1,3 +1,8 @@
+#!/bin/sh
+#hope this thing works across all systems, otherwise mail me please:
+#robos@muon.de
+
+
 echo "THIS CONFIGURE SCRIPT IS STILL HIGHLY EXPERIMENTAL!
 If you think you found a bug, please mail me, thanks! robos@muon.de"
 
@@ -6,9 +11,6 @@ If you think you found a bug, please mail me, thanks! robos@muon.de"
 #below here are variable definitions. They get substituted in the (CC) and 
 #stuff places.
 
-#!/bin/sh
-#hope this thing works across all systems, otherwise mail me please:
-#robos@muon.de
 
 #args check *new*
 #declare -i i=0
@@ -83,6 +85,7 @@ then
 	if [ ! -e /usr/include/dvdread ]; then #muss hier das then hin??
 		echo "Do you have libdvdread installed? I (the script) can't
 find it"
+		echo "You probably need the libdvdread-devel package or something similar installed. If you already have:"
      		echo "Please provide the path to dvdreader.h after
 ./configure --with-dvdread-libs="
 	    	echo "And please mail me the location so that I can fix the
@@ -138,10 +141,19 @@ if [ `uname -s` = FreeBSD ]; then
   else
 	  LDFLAGS="LDFLAGS += -ldvdread -L$libs_dir/lib"
   fi	
+elif [ `uname -m` = x86_64 ]; then #for ia64/AMD64 libraries
+	LDFLAGS="LDFLAGS += -ldvdread -L$libs_dir/lib64"
 else
 	LDFLAGS="LDFLAGS += -ldvdread -L$libs_dir/lib"
 fi
 
+#Solaris 9 needs -lrt 
+if [ `uname -a | grep "SunOS solaris 5.9" ` ]; then
+	LDFLAGS="+LDFLAGS += -ldvdread -lrt -L/usr//lib"
+fi
+
+
+
 #see if a Makefile is present - and kill it ;-)
 if [ -e ./Makefile ]; then
 	rm -f ./Makefile
