@@ -2,5 +2,5 @@
 
 int get_dvd_name(const char *, char *);
 int get_device(char *, char *);
-int get_device_oyo(char *, char *);
-off_t get_vobsize(int title, char *provided_input_dir);
+int get_device_on_your_own(char *, char *);
+off_t get_vob_size(int , char *);
